@@ -35,7 +35,10 @@ class Postgres_Handler:
                     
                     if results.count == 0:
                         results = 'No records found'
-                        
+                except psycopg2.ProgrammingError as ex:
+                    if ex == "no results to fetch":
+                        status = 2
+                        results = "Success"
                 except Exception as ex:
                     status = -1
                     results = f"{ex}"
@@ -126,6 +129,8 @@ class Postgres_Handler:
                 'count': row_count,
                 'records': formatted_rows
             }
+        elif internal_status == 2:
+            records = "No results found"
         else:
             error = data
             
@@ -196,7 +201,7 @@ class Postgres_Handler:
     def update_record(self, **kwargs):
         try:
             values_dict = {}
-            id_key = 'Id'
+            id_key = 'ID'
             clause_section = ''
             
                 #checks for the table name in args
@@ -210,7 +215,7 @@ class Postgres_Handler:
             for key, value in kwargs.items():
                 if key.lower() == id_key.lower() or key.lower() == self.table_name_key: continue
                 
-                clause_section = f' "{key}" = %({key})s AND'
+                clause_section += f' "{key}" = %({key})s AND'
                 values_dict[key] = value
             
             query_string += clause_section[:-4]
