@@ -6,8 +6,8 @@ class Sql_Handler(ABC):
         self.columns = columns
     
     @abstractmethod
-    def set_base_query(self, base_query):
-        self.base_query = base_query
+    def set_table_name(self, table_name):
+        self.table_name = table_name
         
     @abstractmethod
     def set_keywords(self, keywords):
